#include "descriptor/descriptor.h"

int main(void) {

  ITEM	glass,muro,ferro,plastica,argentato,oro,glass_lam;
  ITEM	lampada_ferro,lampada_vetro,lampadina,freccia_plastica,freccia_ferro,freccia_oro,pavimento,parete,paretesin,soffitto,bersaglio_ferro,bersaglio_legno;
  ITEM	scene;

  set_background(0.676,0.861,0.953,TRUE);
  set_ambient_light(1,1,0.7,1);
  create_point_light(4.42,5.94,2.55,0.2,0.2,0.07,3.10,60, "light1");
  create_point_light(-2.13,42.46,-0.60,0.05,0.05,0.01,3.10,180, "light2");

  /*** ATTRIBUTE glass ***/
  glass = create_attribute("glass");
  set_color(glass,0.68,0.86,1,0.5,0.5);
  set_reflectivity(glass,0.3,128);
  set_transparency(glass,0.95,0.95,0.9,1.0);

    /*** ATTRIBUTE glass_lam ***/
  glass_lam = create_attribute("glass_lam");
  set_color(glass_lam,1,1,0.9,0.9,0.9);
  set_reflectivity(glass_lam,0.9,128);
  set_transparency(glass_lam,0.6,0.6,0.6,1.2);
  
  /*** ATTRIBUTE ferro ***/
  ferro = create_attribute("ferro");
  set_color(ferro,0.05,0.05,0.05,0.1,0.8);
  set_reflectivity(ferro,0.2,128);
  
  /*** ATTRIBUTE plastica ***/
  plastica = create_attribute("plastica");
  set_color(plastica,1,0,0,0.8,0.8);

  /*** ATTRIBUTE argentato ***/
  argentato = create_attribute("argentato");
  set_color(argentato,0.9,0.9,0.9,0.8,0.8);
  set_reflectivity(argentato,0.8,128);
  
  /*** ATTRIBUTE oro ***/
  oro = create_attribute("oro");
  set_color(oro,0.8,0.8,0.2,0.8,0.8);
  set_reflectivity(oro,0.4,128);
  
  /*** ATTRIBUTE muro ***/
  muro = create_attribute("muro");
  set_color(muro,0.89,0.8,0.8,0.9,0.9);

  /* LAMPADA */
  lampada_ferro = read_obj("lampada.obj", "ferro_lampada");
  set_attribute(lampada_ferro,ferro);
  
  lampada_vetro = read_nurbs("vetro_lampada.db");
  set_attribute(lampada_vetro,glass);

  lampadina = read_nurbs("lampadina.db");
  set_attribute(lampadina,glass_lam);

  /* BERSAGLIO */
  bersaglio_ferro = read_obj("bersaglio_ferro.obj", "ferro_bersaglio");
  set_attribute(bersaglio_ferro,ferro);
  
  bersaglio_legno = read_nurbs("bersaglio.db");
  set_scale(bersaglio_legno,0.50001,0.50001,0.50001);  
  set_z_rotate(bersaglio_legno,180,1);  
  set_projection_texture(bersaglio_legno,muro,"textures/bersaglio.hr",1,0,1,1);
  set_scale(bersaglio_legno,2,2,2);
  set_z_rotate(bersaglio_legno,180,1);

  /* FRECCIA */  
  freccia_plastica = read_obj("freccia_plastica.obj", "plas_freccia");
  set_scale(freccia_plastica,0.7,0.7,0.7);
  set_translate(freccia_plastica,0.3,0,0.4);
  set_attribute(freccia_plastica,plastica);
  
  freccia_oro = read_nurbs("freccia_ferr.db");
  set_scale(freccia_oro,0.7,0.7,0.7);
  set_translate(freccia_oro,0.3,0,0.4);
  set_attribute(freccia_oro,oro);

  freccia_ferro = read_nurbs("punta_frecc.db");
  set_scale(freccia_ferro,0.7,0.7,0.7);
  set_translate(freccia_ferro,0.3,0,0.4);
  set_attribute(freccia_ferro,argentato);
  
  /* TAVERNA */
  parete = read_nurbs("parete.db");
  set_attribute(parete,muro);
  
  paretesin = read_nurbs("paretesin.db");
  set_attribute(paretesin,muro);
  
  soffitto = read_nurbs("soffitto.db");
  set_attribute(soffitto,muro);
  
  pavimento = read_nurbs("pavimento.db");
  set_scale(pavimento,0.25,0.25,0.25);  
  set_projection_texture(pavimento,muro,"textures/parquet.hr",2,1,1,1);
  set_scale(pavimento,4,4,4);  
  
  scene = create_list(lampada_ferro, "scene");
  scene = insert_in_list(scene,pavimento);
  scene = insert_in_list(scene,parete);
  scene = insert_in_list(scene,paretesin);
  scene = insert_in_list(scene,soffitto);
  scene = insert_in_list(scene,freccia_plastica);
  scene = insert_in_list(scene,freccia_oro);
  scene = insert_in_list(scene,freccia_ferro);
  scene = insert_in_list(scene,lampada_vetro);
  scene = insert_in_list(scene,lampadina);
  scene = insert_in_list(scene,bersaglio_ferro);
  scene = insert_in_list(scene,bersaglio_legno);
    
  save_scene("taverna.md","scene_taverna",scene);
  return(0);
}
